import streamlit as st

from utils import generate_xiaohongshu

# アプリのヘッダー
st.header("人気のレッドブックAIライティングアシスタント ✏️")

# サイドバーでAPIキーを入力
with st.sidebar:
    openai_api_key = st.text_input("OpenAI APIキーを入力してください：", type="password")
    st.markdown("[OpenAI APIキーを取得](https://platform.openai.com/account/api-keys)")

# ユーザー入力（テーマ）
theme = st.text_input("テーマ")
submit = st.button("執筆を開始")

# バリデーション：APIキーが入力されていない場合
if submit and not openai_api_key:
    st.info("OpenAI APIキーを入力してください")
    st.stop()

# バリデーション：テーマが入力されていない場合
if submit and not theme:
    st.info("生成する内容のテーマを入力してください")
    st.stop()

# AIによる執筆処理
if submit:
    with st.spinner("AIが執筆中です。しばらくお待ちください..."):
        result = generate_xiaohongshu(theme, openai_api_key)

    st.divider()  # セクションの区切り線

    # 2カラムのレイアウトを作成
    left_column, right_column = st.columns(2)

    # 左側カラム：タイトル一覧
    with left_column:
        st.markdown("##### レッドブックタイトル1")
        st.write(result.titles[0])
        st.markdown("##### レッドブックタイトル2")
        st.write(result.titles[1])
        st.markdown("##### レッドブックタイトル3")
        st.write(result.titles[2])
        st.markdown("##### レッドブックタイトル4")
        st.write(result.titles[3])
        st.markdown("##### レッドブックタイトル5")
        st.write(result.titles[4])

    # 右側カラム：本文
    with right_column:
        st.markdown("##### レッドブック本文")
        st.write(result.content)
